=====
Usage
=====

The enpt_enmapboxapp GUI can be found in
:menuselection:`QGIS 3.xx --> EnMAP-Box --> Processing Toolbox --> Pre-Processing --> EnMAP processing tool algorithm`


.. image:: ./images/sceenshot_how_to_start_1342x1029.png
    :scale: 75 %

Use the GUI to parameterize EnPT_ according to your input dataset and the desired processing settings.
The input parameters are explained
`here <http://enmap.gitext.gfz-potsdam.de/GFZ_Tools_EnMAP_BOX/EnPT/doc/usage.html#enpt-cli-py>`__.

.. hint::

    Before you start the processing chain, make sure, that the Anaconda root directory is correctly set. It should
    point to the Anaconda installation containing the previously installed `enpt` Python environment.

The status of computation can watched in the log tab and the QGIS Python console.


.. _EnPT: https://gitext.gfz-potsdam.de/EnMAP/GFZ_Tools_EnMAP_BOX/EnPT
